@@ -2,7 +2,7 @@ package Data::XLSX::Parser;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Data::XLSX::Parser::DocumentArchive;
 use Data::XLSX::Parser::Workbook;
@@ -11,6 +11,8 @@ use Data::XLSX::Parser::Styles;
 use Data::XLSX::Parser::Sheet;
 use Data::XLSX::Parser::Relationships;
 
+my $workbook_schema = 'http://schemas.openxmlformats.org/officeDocument/2006/relationships/worksheet';
+
 sub new {
     my ($class) = @_;
 
@@ -55,19 +57,22 @@ sub relationships {
 
 sub sheet {
     my ($self, $sheet_id) = @_;
+    warn 'Data::XLSX::Parser->sheet is obsolete. This method will remove feature release.';
     $self->{_sheet}->{$sheet_id} ||= Data::XLSX::Parser::Sheet->new($self, $self->{_archive}, $sheet_id);
 }
 
 sub sheet_by_rid {
     my ($self, $rid) = @_;
 
-    my $target = $self->relationships->relation_target($rid);
-    unless ($target) {
+    my $relation = $self->relationships->relation($rid);
+    unless ($relation) {
         return;
     }
 
-    if ($target =~ /worksheets\/sheet(\d+).xml/) {
-        return $self->sheet($1);
+    if ($relation->{Type} eq $workbook_schema) {
+        my $target = $relation->{Target};
+        $self->{_sheet}->{$rid} ||=
+            Data::XLSX::Parser::Sheet->new($self, $self->{_archive}, $target);
     }
 }
 
@@ -98,7 +103,13 @@ Data::XLSX::Parser - faster XLSX parser
         my ($row) = @_;
         print Dumper $row;
     });
-    $parser->parse('foo.xlsx');
+    $parser->open('foo.xlsx');
+    
+    # parse sheet with sheet name
+    $parser->sheet_by_rid( $parser->workbook->sheet_id( 'Sheet1' ) );
+    
+    # .. or parse sheet with r:Id
+    $parser->sheet_by_rid(3);
 
 =head1 DESCRIPTION
 
